@@ -15,14 +15,12 @@
 """
 try:
     from PySide6.QtWidgets import QWidget, QTabWidget, QHBoxLayout, QVBoxLayout, QLabel, QTextEdit, QPushButton
-    from PySide6.QtCore import Qt, QSize, QPoint, QTranslator, QCoreApplication, QLocale
-    from PySide6 import QtCore, QtGui, QtWidgets
+    from PySide6.QtCore import Qt, QSize, QTranslator, QCoreApplication, QLocale
     from PySide6.QtGui import QIcon, QFont
     pyside6_is_installed = True
 except:
     from PyQt5.QtWidgets import QWidget, QTabWidget, QHBoxLayout, QVBoxLayout, QLabel, QTextEdit, QPushButton
-    from PyQt5.QtCore import Qt, QSize, QPoint, QTranslator, QCoreApplication, QLocale
-    from PyQt5 import QtCore, QtGui, QtWidgets
+    from PyQt5.QtCore import Qt, QSize, QTranslator, QCoreApplication, QLocale
     from PyQt5.QtGui import QIcon, QFont
     pyside6_is_installed = False
 
@@ -30,13 +28,13 @@ from persepolis.gui import resources
 
 if pyside6_is_installed == True:
     try:
-        from PySide6 import QtSvgWidget
+        from PySide6 import QtSvgWidgets
         qtsvg_available = True
     except:
         qtsvg_available = False
 else:
     try:
-        from PyQt5 import QtSvg as QtSvgWidget
+        from PyQt5 import QtSvg as QtSvgWidgets
         qtsvg_available = True
     except:
         qtsvg_available = False
@@ -69,7 +67,7 @@ class AboutWindow_Ui(QWidget):
             str(self.persepolis_setting.value('settings/icons')) + '/'
 
         self.setMinimumSize(QSize(545, 375))
-        self.setWindowIcon(QIcon.fromTheme('persepolis', QIcon(':/persepolis.svg')))
+        self.setWindowIcon(QIcon.fromTheme('persepolis', QIcon(':/com.github.persepolisdm.persepolis.svg')))
 
         verticalLayout = QVBoxLayout(self)
 
@@ -85,7 +83,7 @@ class AboutWindow_Ui(QWidget):
         # persepolis icon
         if qtsvg_available:
             persepolis_icon_verticalLayout = QVBoxLayout()
-            self.persepolis_icon = QtSvgWidget.QSvgWidget(':/persepolis.svg')
+            self.persepolis_icon = QtSvgWidgets.QSvgWidget(':/com.github.persepolisdm.persepolis.svg')
             self.persepolis_icon.setFixedSize(QSize(64, 64))
 
             persepolis_icon_verticalLayout.addWidget(self.persepolis_icon)
@@ -188,6 +186,46 @@ class AboutWindow_Ui(QWidget):
 
         verticalLayout.addWidget(self.about_tabWidget)
 
+        # Acknowledgments tab
+        self.acknowledgments_tab = QWidget(self)
+        acknowledgments_verticalLayout = QVBoxLayout(self.acknowledgments_tab)
+
+        self.acknowledgments_title_label = QLabel(self.acknowledgments_tab)
+        font.setBold(True)
+        font.setWeight(QFont.Weight.Bold)
+        self.acknowledgments_title_label.setFont(font)
+        self.acknowledgments_title_label.setAlignment(Qt.AlignCenter)
+        acknowledgments_verticalLayout.addWidget(self.acknowledgments_title_label)
+
+        self.acknowledgments_aria2c_label = QLabel(self.acknowledgments_tab)
+        self.acknowledgments_aria2c_label.setAlignment(Qt.AlignCenter)
+        self.acknowledgments_ffmpeg_label = QLabel(self.acknowledgments_tab)
+        self.acknowledgments_ffmpeg_label.setAlignment(Qt.AlignCenter)
+        self.acknowledgments_ytdlp_label = QLabel(self.acknowledgments_tab)
+        self.acknowledgments_ytdlp_label.setAlignment(Qt.AlignCenter)
+        self.acknowledgments_sthp_label = QLabel(self.acknowledgments_tab)
+        self.acknowledgments_sthp_label.setAlignment(Qt.AlignCenter)
+        self.acknowledgments_gost_label = QLabel(self.acknowledgments_tab)
+        self.acknowledgments_gost_label.setAlignment(Qt.AlignCenter)
+
+
+        self.acknowledgments_aria2c_label.setFont(font)
+        self.acknowledgments_ffmpeg_label.setFont(font)
+        self.acknowledgments_ytdlp_label.setFont(font)
+        self.acknowledgments_gost_label.setFont(font)
+
+
+        acknowledgments_verticalLayout.addWidget(self.acknowledgments_aria2c_label)
+        acknowledgments_verticalLayout.addWidget(self.acknowledgments_ytdlp_label)
+        acknowledgments_verticalLayout.addWidget(self.acknowledgments_ffmpeg_label)
+        acknowledgments_verticalLayout.addWidget(self.acknowledgments_sthp_label)
+        acknowledgments_verticalLayout.addWidget(self.acknowledgments_gost_label)
+        acknowledgments_verticalLayout.addStretch(1)
+
+
+
+
+
         # buttons
         button_horizontalLayout = QHBoxLayout()
         button_horizontalLayout.addStretch(1)
@@ -204,7 +242,7 @@ class AboutWindow_Ui(QWidget):
 
         # about_tab
         self.title_label.setText(QCoreApplication.translate("about_ui_tr", "Persepolis Download Manager"))
-        self.version_label.setText(QCoreApplication.translate("about_ui_tr", "Version 4.0.0"))
+        self.version_label.setText(QCoreApplication.translate("about_ui_tr", "Version 4.1.0"))
         self.site2_label.setText(QCoreApplication.translate("about_ui_tr",
                                                             "<a href=https://persepolisdm.github.io>https://persepolisdm.github.io</a>",
                                                             "TRANSLATORS NOTE: YOU REALLY DON'T NEED TO TRANSLATE THIS PART!"))
@@ -218,16 +256,33 @@ class AboutWindow_Ui(QWidget):
                                                               "TRANSLATORS NOTE: YOU REALLY DON'T NEED TO TRANSLATE THIS PART!"))
 
         # developers_tab
-        self.developers_title_label.setText(QCoreApplication.translate('about_ui_tr', 'Developers:'))
+        self.developers_title_label.setText(QCoreApplication.translate('about_ui_tr', 'Acknowledgments:'))
 
         self.name_label.setText(QCoreApplication.translate("about_ui_tr",
-                                                           "\nAliReza AmirSamimi\nMohammadreza Abdollahzadeh\nSadegh Alirezaie\nMostafa Asadi\nMohammadAmin Vahedinia\nJafar Akhondali\nH.Rostami\nEhsan Titish",
+                                                           "\nAliReza AmirSamimi\nMohammadreza Abdollahzadeh\nSadegh Alirezaie\nMostafa Asadi\nJafar Akhondali\nKia Hamedi\nH.Rostami\nEhsan Titish\nMohammadAmin Vahedinia",
                                                            "TRANSLATORS NOTE: YOU REALLY DON'T NEED TO TRANSLATE THIS PART!"))
 
         self.contributors_thank_label.setText(QCoreApplication.translate('about_ui_tr', 'Special thanks to:'))
         self.contributors_link_label.setText(
             "<a href=https://github.com/persepolisdm/persepolis/graphs/contributors>our contributors</a>")
 
+        # Acknowledgments
+        self.acknowledgments_title_label.setText(QCoreApplication.translate('about_ui_tr', 'Acknowledgments:'))
+
+        self.acknowledgments_aria2c_label.setText(QCoreApplication.translate("about_ui_tr",
+                                                                           "<a href=https://github.com/aria2/aria2>Aria2c project</a>"))
+        self.acknowledgments_ytdlp_label.setText(QCoreApplication.translate("about_ui_tr",
+                                                                           "<a href=https://github.com/yt-dlp/yt-dlp>YT-DLP project</a>"))
+        self.acknowledgments_ffmpeg_label.setText(QCoreApplication.translate("about_ui_tr",
+                                                                           "<a href=https://github.com/ffmpeg/ffmpeg>FFmpeg project</a>"))
+        self.acknowledgments_sthp_label.setText(QCoreApplication.translate("about_ui_tr",
+                                                                           "<a href=https://github.com/KaranGauswami/socks-to-http-proxy>Socks to http proxy project</a>"))
+        self.acknowledgments_gost_label.setText(QCoreApplication.translate("about_ui_tr",
+                                                                           "<a href=https://github.com/ginuerzh/gost>Gost project</a>"))
+
+
+
+
         # License
         self.license_text.setPlainText("""
             This program is free software: you can redistribute it and/or modify
@@ -247,6 +302,8 @@ class AboutWindow_Ui(QWidget):
         # tabs
         self.about_tabWidget.addTab(self.about_tab, QCoreApplication.translate("about_ui_tr", "About Persepolis"))
         self.about_tabWidget.addTab(self.developers_tab, QCoreApplication.translate("about_ui_tr", "Developers"))
+        self.about_tabWidget.addTab(self.acknowledgments_tab, QCoreApplication.translate("about_ui_tr", "Acknowledgments"))
+
         self.about_tabWidget.addTab(self.translators_tab, QCoreApplication.translate("about_ui_tr", "Translators"))
         self.about_tabWidget.addTab(self.license_tab, QCoreApplication.translate("about_ui_tr", "License"))
 
