@@ -15,14 +15,15 @@
 """
 
 try:
-    from PySide6.QtWidgets import QTabWidget, QDoubleSpinBox, QPushButton, QComboBox, QSpinBox, QVBoxLayout, QHBoxLayout, QLabel, QApplication, QWidget, QFileDialog, QMessageBox, QSizePolicy, QGridLayout, QCheckBox, QFrame, QLineEdit, QPushButton
+    from PySide6.QtWidgets import QTabWidget, QDoubleSpinBox, QPushButton, QComboBox, QSpinBox, QVBoxLayout, QHBoxLayout, QLabel, QWidget, QGridLayout, QCheckBox, QFrame, QLineEdit, QRadioButton
+
     from PySide6.QtCore import Qt, QTranslator, QCoreApplication, QLocale
-    from PySide6 import QtCore, QtGui, QtWidgets
+    from PySide6 import QtCore
     from PySide6.QtGui import QIcon
 except:
-    from PyQt5.QtWidgets import QTabWidget, QDoubleSpinBox, QPushButton, QComboBox, QSpinBox, QVBoxLayout, QHBoxLayout, QLabel, QApplication, QWidget, QFileDialog, QMessageBox, QSizePolicy, QGridLayout, QCheckBox, QFrame, QLineEdit, QPushButton
+    from PyQt5.QtWidgets import QTabWidget, QDoubleSpinBox, QPushButton, QComboBox, QSpinBox, QVBoxLayout, QHBoxLayout, QLabel, QWidget, QGridLayout, QCheckBox, QFrame, QLineEdit, QRadioButton
     from PyQt5.QtCore import Qt, QTranslator, QCoreApplication, QLocale
-    from PyQt5 import QtCore, QtGui, QtWidgets
+    from PyQt5 import QtCore
     from PyQt5.QtGui import QIcon
 
 from persepolis.gui import resources
@@ -54,7 +55,7 @@ class AddLinkWindow_Ui(QWidget):
             str(self.persepolis_setting.value('settings/icons')) + '/'
 
         self.setMinimumSize(QtCore.QSize(520, 425))
-        self.setWindowIcon(QIcon.fromTheme('persepolis', QIcon(':/persepolis.svg')))
+        self.setWindowIcon(QIcon.fromTheme('persepolis', QIcon(':/com.github.persepolisdm.persepolis.svg')))
 
         # main layout
         window_verticalLayout = QVBoxLayout()
@@ -181,8 +182,21 @@ class AddLinkWindow_Ui(QWidget):
 
         proxy_verticalLayout.addWidget(self.proxy_frame)
 
-        proxy_verticalLayout.addStretch(1)
+        # type of proxy
+        self.http_radioButton = QRadioButton(self.proxy_frame)
+        gridLayout.addWidget(self.http_radioButton, 4, 0, 1, 1)
 
+        self.https_radioButton = QRadioButton(self.proxy_frame)
+        gridLayout.addWidget(self.https_radioButton, 5, 0, 1, 1)
+
+        # hide this widget until https support
+        self.https_radioButton.hide()
+
+        self.socks5_radioButton = QRadioButton(self.proxy_frame)
+        gridLayout.addWidget(self.socks5_radioButton, 6, 0, 1, 1)
+
+
+        proxy_verticalLayout.addStretch(1)
         self.add_link_tabWidget.addTab(self.proxy_tab, '')
 
         # more options tab
@@ -423,6 +437,10 @@ class AddLinkWindow_Ui(QWidget):
         self.proxy_user_label.setText(QCoreApplication.translate("addlink_ui_tr", "Proxy username: "))
         self.port_label.setText(QCoreApplication.translate("addlink_ui_tr", "Port:"))
 
+        self.http_radioButton.setText(QCoreApplication.translate("addlink_ui_tr", "HTTP"))
+        self.https_radioButton.setText(QCoreApplication.translate("addlink_ui_tr", "HTTPS"))
+        self.socks5_radioButton.setText(QCoreApplication.translate("addlink_ui_tr", "SOCKS5"))
+
         self.download_checkBox.setText(QCoreApplication.translate("addlink_ui_tr", "Download username and password"))
         self.download_user_label.setText(QCoreApplication.translate("addlink_ui_tr", "Download username: "))
         self.download_pass_label.setText(QCoreApplication.translate("addlink_ui_tr", "Download password: "))
