@@ -13,13 +13,13 @@
 #    You should have received a copy of the GNU General Public License
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 try:
-    from PySide6.QtWidgets import QHeaderView, QDoubleSpinBox, QPushButton, QComboBox,  QMenu, QTreeView, QSplitter, QSizePolicy, QGridLayout, QHBoxLayout, QVBoxLayout, QMenu, QTableWidgetItem, QAbstractItemView, QApplication, QToolBar, QMenuBar, QStatusBar, QTableWidget, QMainWindow, QWidget, QFrame, QAbstractItemView, QCheckBox, QSpinBox, QLabel
-    from PySide6.QtGui import QShortcut, QAction, QCursor, QKeySequence, QIcon, QStandardItemModel, QStandardItem
-    from PySide6.QtCore import QCoreApplication, QRect, QSize, Qt, QTranslator, QLocale
+    from PySide6.QtWidgets import QHeaderView, QDoubleSpinBox, QPushButton, QComboBox,  QMenu, QTreeView, QSplitter, QHBoxLayout, QVBoxLayout, QTableWidgetItem, QAbstractItemView, QToolBar, QMenuBar, QStatusBar, QTableWidget, QMainWindow, QWidget, QFrame, QCheckBox, QLabel
+    from PySide6.QtGui import QShortcut, QAction, QCursor, QIcon, QStandardItemModel
+    from PySide6.QtCore import QCoreApplication, QRect, Qt, QTranslator, QLocale
 except:
-    from PyQt5.QtWidgets import QHeaderView, QShortcut, QDoubleSpinBox, QPushButton, QComboBox,  QMenu, QTreeView, QSplitter, QSizePolicy, QGridLayout, QHBoxLayout, QVBoxLayout, QMenu, QTableWidgetItem, QAbstractItemView, QApplication, QToolBar, QMenuBar, QStatusBar, QTableWidget, QAction, QMainWindow, QWidget, QFrame, QAbstractItemView, QCheckBox, QSpinBox, QLabel
-    from PyQt5.QtGui import QCursor, QKeySequence, QIcon, QStandardItemModel, QStandardItem
-    from PyQt5.QtCore import QCoreApplication, QRect, QSize, Qt, QTranslator, QLocale
+    from PyQt5.QtWidgets import QHeaderView, QShortcut, QDoubleSpinBox, QPushButton, QComboBox,  QTreeView, QSplitter, QHBoxLayout, QVBoxLayout, QMenu, QTableWidgetItem, QAbstractItemView, QToolBar, QMenuBar, QStatusBar, QTableWidget, QAction, QMainWindow, QWidget, QFrame, QCheckBox, QLabel
+    from PyQt5.QtGui import QCursor, QIcon, QStandardItemModel 
+    from PyQt5.QtCore import QCoreApplication, QRect, Qt, QTranslator, QLocale
 
 from persepolis.gui import resources
 from persepolis.gui.customized_widgets import MyQDateTimeEdit
@@ -140,8 +140,6 @@ class MenuWidget(QPushButton):
 
         helpMenu.addAction(self.parent.issueAction)
 
-        helpMenu.addAction(self.parent.updateAction)
-
         helpMenu.addAction(self.parent.logAction)
 
         helpMenu.addAction(self.parent.helpAction)
@@ -224,7 +222,7 @@ class MainWindow_Ui(QMainWindow):
             str(self.persepolis_setting.value('settings/icons')) + '/'
 
         self.setWindowTitle(QCoreApplication.translate("mainwindow_ui_tr", "Persepolis Download Manager"))
-        self.setWindowIcon(QIcon.fromTheme('persepolis', QIcon(':/persepolis.svg')))
+        self.setWindowIcon(QIcon.fromTheme('persepolis', QIcon(':/com.github.persepolisdm.persepolis.svg')))
 
         self.centralwidget = QWidget(self)
         self.verticalLayout = QVBoxLayout(self.centralwidget)
@@ -479,13 +477,13 @@ class MainWindow_Ui(QMainWindow):
         # toolBar
         self.toolBar2 = QToolBar(self)
         self.addToolBar(Qt.TopToolBarArea, self.toolBar2)
-        self.toolBar2.setWindowTitle(QCoreApplication.translate("mainwindow_ui_tr", 'Menu'))
+#         self.toolBar2.setWindowTitle(QCoreApplication.translate("mainwindow_ui_tr", 'Menu'))
         self.toolBar2.setFloatable(False)
         self.toolBar2.setMovable(False)
 
         self.toolBar = QToolBar(self)
         self.addToolBar(Qt.TopToolBarArea, self.toolBar)
-        self.toolBar.setWindowTitle(QCoreApplication.translate("mainwindow_ui_tr", 'Toolbar'))
+#         self.toolBar.setWindowTitle(QCoreApplication.translate("mainwindow_ui_tr", 'Toolbar'))
         self.toolBar.setFloatable(False)
         self.toolBar.setMovable(False)
 
@@ -715,11 +713,6 @@ class MainWindow_Ui(QMainWindow):
                                    self, statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'Report an issue'), triggered=self.reportIssue)
         helpMenu.addAction(self.issueAction)
 
-        # updateAction
-        self.updateAction = QAction(QIcon(icons + 'about'), QCoreApplication.translate("mainwindow_ui_tr", 'Check for Newer Version'),
-                                    self, statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'Check for newer release'), triggered=self.newUpdate)
-        helpMenu.addAction(self.updateAction)
-
         # logAction
         self.logAction = QAction(QIcon(icons + 'about'), QCoreApplication.translate("mainwindow_ui_tr", 'Show Log File'),
                                  self, statusTip=QCoreApplication.translate("mainwindow_ui_tr", 'Help'), triggered=self.showLog)
