@@ -14,11 +14,11 @@
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 try:
-    from PySide6.QtWidgets import QAbstractItemView, QTableWidget, QTableWidgetItem, QCheckBox, QVBoxLayout, QHBoxLayout, QFrame, QWidget, QLabel, QLineEdit, QTabWidget, QSpinBox, QPushButton, QDial, QComboBox, QFontComboBox, QSpacerItem, QSizePolicy
+    from PySide6.QtWidgets import QAbstractItemView, QTableWidget, QTableWidgetItem, QCheckBox, QVBoxLayout, QHBoxLayout, QFrame, QWidget, QLabel, QLineEdit, QTabWidget, QSpinBox, QPushButton, QDial, QComboBox, QFontComboBox
     from PySide6.QtCore import Qt, QTranslator, QCoreApplication, QLocale
     from PySide6.QtGui import QIcon
 except:
-    from PyQt5.QtWidgets import QAbstractItemView, QTableWidget, QTableWidgetItem, QCheckBox, QVBoxLayout, QHBoxLayout, QFrame, QWidget, QLabel, QLineEdit, QTabWidget, QSpinBox, QPushButton, QDial, QComboBox, QFontComboBox, QSpacerItem, QSizePolicy
+    from PyQt5.QtWidgets import QAbstractItemView, QTableWidget, QTableWidgetItem, QCheckBox, QVBoxLayout, QHBoxLayout, QFrame, QWidget, QLabel, QLineEdit, QTabWidget, QSpinBox, QPushButton, QDial, QComboBox, QFontComboBox
     from PyQt5.QtCore import Qt, QTranslator, QCoreApplication, QLocale
     from PyQt5.QtGui import QIcon
 
@@ -28,7 +28,6 @@ from persepolis.gui import resources
 class KeyCapturingWindow_Ui(QWidget):
     def __init__(self, persepolis_setting):
         super().__init__()
-        icon = QIcon()
 
         self.persepolis_setting = persepolis_setting
 
@@ -39,7 +38,7 @@ class KeyCapturingWindow_Ui(QWidget):
         if self.translator.load(':/translations/locales/ui_' + locale, 'ts'):
             QCoreApplication.installTranslator(self.translator)
 
-        self.setWindowIcon(QIcon.fromTheme('persepolis', QIcon(':/persepolis.svg')))
+        self.setWindowIcon(QIcon.fromTheme('persepolis', QIcon(':/com.github.persepolisdm.persepolis.svg')))
         self.setWindowTitle(QCoreApplication.translate("setting_ui_tr", 'Preferences'))
 
         # set ui direction
@@ -85,7 +84,6 @@ class KeyCapturingWindow_Ui(QWidget):
 class Setting_Ui(QWidget):
     def __init__(self, persepolis_setting):
         super().__init__()
-        icon = QIcon()
 
         self.persepolis_setting = persepolis_setting
 
@@ -96,7 +94,7 @@ class Setting_Ui(QWidget):
         if self.translator.load(':/translations/locales/ui_' + locale, 'ts'):
             QCoreApplication.installTranslator(self.translator)
 
-        self.setWindowIcon(QIcon.fromTheme('persepolis', QIcon(':/persepolis.svg')))
+        self.setWindowIcon(QIcon.fromTheme('persepolis', QIcon(':/com.github.persepolisdm.persepolis.svg')))
         self.setWindowTitle(QCoreApplication.translate("setting_ui_tr", 'Preferences'))
 
         # set ui direction
@@ -199,6 +197,10 @@ class Setting_Ui(QWidget):
         self.dont_check_certificate_checkBox = QCheckBox(self.download_options_tab)
         download_options_tab_verticalLayout.addWidget(self.dont_check_certificate_checkBox)
 
+        # remote time
+        self.remote_time_checkBox = QCheckBox(self.download_options_tab)
+        download_options_tab_verticalLayout.addWidget(self.remote_time_checkBox)
+
         # change aria2 path
         aria2_path_verticalLayout = QVBoxLayout()
 
@@ -242,20 +244,6 @@ class Setting_Ui(QWidget):
 
         save_as_tab_verticalLayout.addLayout(self.download_folder_horizontalLayout)
 
-        # temp_download_folder
-        self.temp_horizontalLayout = QHBoxLayout()
-
-        self.temp_download_label = QLabel(self.save_as_tab)
-        self.temp_horizontalLayout.addWidget(self.temp_download_label)
-
-        self.temp_download_lineEdit = QLineEdit(self.save_as_tab)
-        self.temp_horizontalLayout.addWidget(self.temp_download_lineEdit)
-
-        self.temp_download_pushButton = QPushButton(self.save_as_tab)
-        self.temp_horizontalLayout.addWidget(self.temp_download_pushButton)
-
-        save_as_tab_verticalLayout.addLayout(self.temp_horizontalLayout)
-
         # create subfolder
         self.subfolder_checkBox = QCheckBox(self.save_as_tab)
         save_as_tab_verticalLayout.addWidget(self.subfolder_checkBox)
@@ -590,6 +578,13 @@ class Setting_Ui(QWidget):
         self.dont_check_certificate_checkBox.setToolTip(
                 QCoreApplication.translate("setting_ui_tr", "<html><head/><body><p>This option avoids SSL/TLS handshake failure. But use it at your own risk!</p></body></html>"))
 
+
+        self.remote_time_checkBox.setText(QCoreApplication.translate("setting_ui_tr", "Remote time"))
+        self.remote_time_checkBox.setToolTip(
+                QCoreApplication.translate("setting_ui_tr", "<html><head/><body><p>Retrieve timestamp of the remote file from the remote HTTP/FTP server and if it is available, apply it to the local file.</p></body></html>"))
+
+
+
         self.aria2_path_checkBox.setText(QCoreApplication.translate("setting_ui_tr", 'Change Aria2 default path'))
         self.aria2_path_pushButton.setText(QCoreApplication.translate("setting_ui_tr", 'Change'))
         aria2_path_tooltip = QCoreApplication.translate(
@@ -604,9 +599,6 @@ class Setting_Ui(QWidget):
         self.download_folder_label.setText(QCoreApplication.translate("setting_ui_tr", "Download folder: "))
         self.download_folder_pushButton.setText(QCoreApplication.translate("setting_ui_tr", "Change"))
 
-        self.temp_download_label.setText(QCoreApplication.translate("setting_ui_tr", "Temporary download folder: "))
-        self.temp_download_pushButton.setText(QCoreApplication.translate("setting_ui_tr", "Change"))
-
         self.subfolder_checkBox.setText(QCoreApplication.translate(
             "setting_ui_tr", "Create subfolders for Music,Videos, ... in default download folder"))
 
