@@ -15,11 +15,11 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
 try:
-    from PySide6.QtWidgets import QHBoxLayout, QApplication, QFileDialog, QCheckBox, QLineEdit, QPushButton
+    from PySide6.QtWidgets import QApplication, QFileDialog
     from PySide6.QtCore import Qt, QPoint, QSize, QDir, QThread, Signal
     from PySide6.QtGui import QIcon
 except:
-    from PyQt5.QtWidgets import QHBoxLayout, QApplication, QFileDialog, QCheckBox, QLineEdit, QPushButton
+    from PyQt5.QtWidgets import QApplication, QFileDialog
     from PyQt5.QtCore import Qt, QPoint, QSize, QDir, QThread
     from PyQt5.QtGui import QIcon
     from PyQt5.QtCore import pyqtSignal as Signal
@@ -66,7 +66,7 @@ class AddLinkSpiderThread(QThread):
 
 
 class AddLinkWindow(AddLinkWindow_Ui):
-    def __init__(self, parent, callback, persepolis_setting, plugin_add_link_dictionary={}):
+    def __init__(self, parent, callback, persepolis_setting, socks5_to_http_convertor_is_installed, plugin_add_link_dictionary={}):
         super().__init__(persepolis_setting)
         self.callback = callback
         self.plugin_add_link_dictionary = plugin_add_link_dictionary
@@ -137,7 +137,27 @@ class AddLinkWindow(AddLinkWindow_Ui):
         if (settings_download_user):
             self.download_user_lineEdit.setText(str(settings_download_user))
 
-# get categories name and add them to add_queue_comboBox
+        # http or socks5 initialization
+        settings_proxy_type = self.persepolis_setting.value(
+            'add_link_initialization/proxy_type', None)
+
+        # default is http
+        if not(socks5_to_http_convertor_is_installed):
+            self.socks5_radioButton.setEnabled(False)
+        else:
+            self.socks5_radioButton.setEnabled(True)
+
+        if settings_proxy_type == 'socks5':
+
+            self.socks5_radioButton.setChecked(True)
+
+        elif settings_proxy_type == 'https':
+            self.https_radioButton.setChecked(True)
+
+        else:
+            self.http_radioButton.setChecked(True)
+ 
+        # get categories name and add them to add_queue_comboBox
         categories_list = self.parent.persepolis_db.categoriesList()
         for queue in categories_list:
             if queue != 'All Downloads':
@@ -348,6 +368,25 @@ class AddLinkWindow(AddLinkWindow_Ui):
         self.persepolis_setting.setValue(
             'add_link_initialization/download_user', self.download_user_lineEdit.text())
 
+        # http, https or socks5 proxy
+        if self.http_radioButton.isChecked() == True:
+
+            proxy_type = 'http'
+            self.persepolis_setting.setValue(
+                'add_link_initialization/proxy_type', 'http')
+
+        elif self.https_radioButton.isChecked() == True:
+
+            proxy_type = 'https'
+            self.persepolis_setting.setValue(
+                'add_link_initialization/proxy_type', 'https')
+
+        else:
+
+            proxy_type = 'socks5'
+            self.persepolis_setting.setValue(
+                'add_link_initialization/proxy_type', 'socks5')
+
         # Check 'Remember path' and change default path if needed
         if self.folder_checkBox.isChecked() == True:
             self.persepolis_setting.setValue(
@@ -359,16 +398,20 @@ class AddLinkWindow(AddLinkWindow_Ui):
             port = None
             proxy_user = None
             proxy_passwd = None
+            proxy_type = None
         else:
             ip = self.ip_lineEdit.text()
             if not(ip):
                 ip = None
+
             port = self.port_spinBox.value()
             if not(port):
                 port = None
+
             proxy_user = self.proxy_user_lineEdit.text()
             if not(proxy_user):
                 proxy_user = None
+
             proxy_passwd = self.proxy_pass_lineEdit.text()
             if not(proxy_passwd):
                 proxy_passwd = None
@@ -448,7 +491,7 @@ class AddLinkWindow(AddLinkWindow_Ui):
         # save information in a dictionary(add_link_dictionary).
         self.add_link_dictionary = {'referer': referer, 'header': header, 'user_agent': user_agent, 'load_cookies': load_cookies,
                                     'out': out, 'start_time': start_time, 'end_time': end_time, 'link': link, 'ip': ip,
-                                    'port': port, 'proxy_user': proxy_user, 'proxy_passwd': proxy_passwd,
+                                    'port': port, 'proxy_user': proxy_user, 'proxy_passwd': proxy_passwd, 'proxy_type': proxy_type,
                                     'download_user': download_user, 'download_passwd': download_passwd,
                                     'connections': connections, 'limit_value': limit, 'download_path': download_path}
 
