@@ -16,11 +16,11 @@
 try:
     from PySide6.QtGui import QFont
     from PySide6.QtWidgets import QApplication, QStyleFactory
-    from PySide6.QtCore import QFile, QTextStream, QCoreApplication, QSettings, Qt
+    from PySide6.QtCore import QFile, QTextStream, QSettings, Qt
 except:
     from PyQt5.QtGui import QFont
     from PyQt5.QtWidgets import QApplication, QStyleFactory
-    from PyQt5.QtCore import QFile, QTextStream, QCoreApplication, QSettings, Qt
+    from PyQt5.QtCore import QFile, QTextStream, QSettings, Qt
 
 from persepolis.gui import resources
 import traceback
@@ -48,7 +48,6 @@ if os_type in (OS.UNIX_LIKE + [OS.OSX]):
 
 
 # initialization
-
 # find home address
 home_address = os.path.expanduser("~")
 
@@ -85,7 +84,6 @@ else:  # for windows
     from win32event import CreateMutex
     from win32api import GetLastError
     from winerror import ERROR_ALREADY_EXISTS
-    from sys import exit
 
     handle = CreateMutex(None, 1, 'persepolis_download_manager')
 
@@ -96,6 +94,8 @@ else:  # for windows
 
 # run persepolis mainwindow
 if lock_file_validation:
+
+    # execute initialization script
     from persepolis.scripts import initialization
     from persepolis.scripts.mainwindow import MainWindow
 
@@ -103,7 +103,7 @@ if lock_file_validation:
     if os_type in OS.UNIX_LIKE:
         try:
             from setproctitle import setproctitle
-            setproctitle("persepolis")
+            setproctitle("persepolisdm")
         except:
             from persepolis.scripts import logger
             logger.sendToLog('setproctitle is not installed!', "ERROR")
@@ -167,7 +167,7 @@ parser.add_argument('--tray', action='store_true',
                     help="Persepolis is starting in tray icon. It's useful when you want to put persepolis in system's startup.")
 parser.add_argument('--parent-window', action='store', nargs=1,
                     help='this switch is used for chrome native messaging in Windows')
-parser.add_argument('--version', action='version', version='Persepolis Download Manager 4.0.0')
+parser.add_argument('--version', action='version', version='Persepolis Download Manager 4.1.0')
 
 
 # Clears unwanted args ( like args from Browers via NHM )
@@ -376,16 +376,6 @@ def main():
         # set color_scheme and style
         # see palettes.py and setting.py
 
-        # this line is added fot fixing persepolis view in HighDpi displays
-        # more information at: https://doc.qt.io/qt-5/highdpi.html
-        try:
-            QApplication.setAttribute(Qt.AA_EnableHighDpiScaling)
-        except:
-            from persepolis.scripts import logger
-
-            # write error_message in log file.
-            logger.sendToLog('Qt.AA_EnableHighDpiScaling is not available!', "ERROR")
-
 
         # create QApplication
         persepolis_download_manager = PersepolisApplication(sys.argv)
@@ -404,12 +394,25 @@ def main():
             # write error_message in log file.
             logger.sendToLog('Qt.AA_UseHighDpiPixmaps is not available!', "ERROR")
 
+        # this line is added fot fixing persepolis view in HighDpi displays
+        # more information at: https://doc.qt.io/qt-5/highdpi.html
+        try:
+            persepolis_download_manager.setAttribute(Qt.AA_EnableHighDpiScaling)
+        except:
+            from persepolis.scripts import logger
+
+            # write error_message in log file.
+            logger.sendToLog('Qt.AA_EnableHighDpiScaling is not available!', "ERROR")
+
+
         # set organization name and domain and application name
-        QCoreApplication.setOrganizationName('persepolis_download_manager')
-        QCoreApplication.setApplicationName('persepolis')
+        persepolis_download_manager.setOrganizationName('com.github.persepolisdm.persepolis')
+        persepolis_download_manager.setApplicationName('PersepolisDM')
+        persepolis_download_manager.setDesktopFileName('com.github.persepolisdm.persepolis')
+        persepolis_download_manager.setApplicationVersion('4.1.0')
 
         # Persepolis setting
-        persepolis_download_manager.setting = QSettings()
+        persepolis_download_manager.setting = QSettings('persepolis_download_manager', 'persepolis')
 
         # get user's desired font and style , ... from setting
         custom_font = persepolis_download_manager.setting.value('settings/custom-font')
