@@ -28,7 +28,6 @@ from persepolis.scripts.useful_tools import returnDefaultSettings
 from persepolis.scripts import osCommands
 from persepolis.scripts import startup
 import platform
-import copy
 import sys
 import os
 
@@ -84,11 +83,18 @@ class PreferencesWindow(Setting_Ui):
         self.rpc_port_spinbox.setValue(
             int(self.persepolis_setting.value('rpc-port')))
 
+        # check certificate
         if str(self.persepolis_setting.value('dont-check-certificate')) == 'yes':
             self.dont_check_certificate_checkBox.setChecked(True)
         else:
             self.dont_check_certificate_checkBox.setChecked(False)
 
+        # remote time
+        if str(self.persepolis_setting.value('remote-time')) == 'yes':
+            self.remote_time_checkBox.setChecked(True)
+        else:
+            self.remote_time_checkBox.setChecked(False)
+
 
         # add support for other languages
         locale = str(self.persepolis_setting.value('settings/locale'))
@@ -125,8 +131,6 @@ class PreferencesWindow(Setting_Ui):
         # save_as_tab
         self.download_folder_lineEdit.setText(
             str(self.persepolis_setting.value('download_path')))
-        self.temp_download_lineEdit.setText(
-            str(self.persepolis_setting.value('download_path_temp')))
 
         # subfolder
         if str(self.persepolis_setting.value('subfolder')) == 'yes':
@@ -161,7 +165,7 @@ class PreferencesWindow(Setting_Ui):
             self.style_comboBox.setCurrentIndex(current_style_index)
 
         # available language
-        available_language = ['en_US', 'fa_IR', 'ar', 'zh_CN', 'fr_FR', 'pl_PL', 'nl_NL', 'pt_BR', 'es_ES', 'hu', 'tr', 'tr_TR']
+        available_language = ['en_US', 'fa_IR','ar', 'es_ES', 'fr_FR', 'ko', 'pl_PL', 'pt', 'ru', 'tr', 'zh_CN', 'de', 'hu', 'nl_NL', 'pt_BR', 'sv', 'tr_TR', 'zh_TW']
         for lang in available_language:
             self.lang_comboBox.addItem(str(QLocale(lang).nativeLanguageName()), lang)
 
@@ -190,6 +194,10 @@ class PreferencesWindow(Setting_Ui):
             str(self.persepolis_setting.value('notification')))
         self.notification_comboBox.setCurrentIndex(current_notification_index)
 
+        if os_type not in OS.UNIX_LIKE:
+            self.notification_comboBox.hide()
+            self.notification_label.hide()
+
         # set font
         font_setting = QFont()
         font_setting.setFamily(str(self.persepolis_setting.value('font')))
@@ -210,9 +218,6 @@ class PreferencesWindow(Setting_Ui):
         self.download_folder_lineEdit.setEnabled(False)
         self.download_folder_pushButton.clicked.connect(
             self.downloadFolderPushButtonClicked)
-        self.temp_download_lineEdit.setEnabled(False)
-        self.temp_download_pushButton.clicked.connect(
-            self.tempDownloadPushButtonClicked)
 
         # dial
         self.volume_dial.setNotchesVisible(True)
@@ -657,18 +662,6 @@ class PreferencesWindow(Setting_Ui):
             self.persepolis_setting.setValue(
                 'settings/download_path', str(fname))
 
-    def tempDownloadPushButtonClicked(self, button):
-
-        download_path_temp = str(
-            self.persepolis_setting.value('settings/download_path_temp'))
-        fname = QFileDialog.getExistingDirectory(
-            self, 'Open f', download_path_temp)
-
-        if fname:
-            self.temp_download_lineEdit.setText(fname)
-            self.persepolis_setting.setValue(
-                'settings/download_path_temp', str(fname))
-
     def dialChanged(self, dial):
 
         self.volume_label.setText('Volume : ' + str(self.volume_dial.value()))
@@ -697,11 +690,12 @@ class PreferencesWindow(Setting_Ui):
         # dont_check_certificate_checkBox
         self.dont_check_certificate_checkBox.setChecked(False)
 
+        # uncheck remote time 
+        self.remote_time_checkBox.setChecked(False)
+
         # save_as_tab
         self.download_folder_lineEdit.setText(
             str(self.setting_dict['download_path']))
-        self.temp_download_lineEdit.setText(
-            str(self.setting_dict['download_path_temp']))
 
         self.subfolder_checkBox.setChecked(True)
 
@@ -839,8 +833,6 @@ class PreferencesWindow(Setting_Ui):
             'rpc-port', self.rpc_port_spinbox.value())
         self.persepolis_setting.setValue(
             'download_path', self.download_folder_lineEdit.text())
-        self.persepolis_setting.setValue(
-            'download_path_temp', self.temp_download_lineEdit.text())
         self.persepolis_setting.setValue(
             'sound-volume', self.volume_dial.value())
         self.persepolis_setting.setValue(
@@ -858,6 +850,12 @@ class PreferencesWindow(Setting_Ui):
         else:
             self.persepolis_setting.setValue('dont-check-certificate', 'no')
 
+        # remote time 
+        if self.remote_time_checkBox.isChecked():
+            self.persepolis_setting.setValue('remote-time', 'yes')
+        else:
+            self.persepolis_setting.setValue('remote-time', 'no')
+
 
 
         # changing icons
@@ -977,15 +975,15 @@ class PreferencesWindow(Setting_Ui):
         if self.startup_checkbox.isChecked():
             self.persepolis_setting.setValue('startup', 'yes')
 
-            if not(startup.checkstartup()):  # checking existence of Persepolis in  system's startup
+            if not(startup.checkStartUp()):  # checking existence of Persepolis in  system's startup
 
-                startup.addstartup()  # adding Persepolis to system's startup
+                startup.addStartUp(self.parent)  # adding Persepolis to system's startup
         else:
             self.persepolis_setting.setValue('startup', 'no')
 
-            if startup.checkstartup():  # checking existence of Persepolis in  system's startup
+            if startup.checkStartUp():  # checking existence of Persepolis in  system's startup
 
-                startup.removestartup()  # removing Persepolis from system's startup
+                startup.removeStartUp()  # removing Persepolis from system's startup
 
         # keep_awake_checkBox
         if self.keep_awake_checkBox.isChecked():
@@ -995,14 +993,12 @@ class PreferencesWindow(Setting_Ui):
             self.persepolis_setting.setValue('awake', 'no')
             self.parent.keep_awake_checkBox.setChecked(False)
 
-        # this section  creates temporary download folder and download folder and
+        # this section  creates download folder and
         # download sub folders if they did not existed.
 
-        download_path_temp = self.persepolis_setting.value(
-            'download_path_temp')
         download_path = self.persepolis_setting.value('download_path')
 
-        folder_list = [download_path_temp, download_path]
+        folder_list = [download_path]
 
         if self.subfolder_checkBox.isChecked():
             self.persepolis_setting.setValue('subfolder', 'yes')
@@ -1164,7 +1160,7 @@ class PreferencesWindow(Setting_Ui):
         show_message_box = False
         for key in self.first_key_value_dict.keys():
             if self.first_key_value_dict[key] != self.second_key_value_dict[key]:
-                if key in ['locale', 'aria2_path', 'download_path_temp', 'download_path', 'custom-font', 'rpc-port', 'max-tries', 'retry-wait', 'timeout', 'connections', 'style', 'font', 'font-size', 'color-scheme']:
+                if key in ['locale', 'aria2_path', 'download_path', 'custom-font', 'rpc-port', 'max-tries', 'retry-wait', 'timeout', 'connections', 'style', 'font', 'font-size', 'color-scheme']:
                     show_message_box = True
 
         # if any thing changed that needs restarting, then notify user about "Some changes take effect after restarting persepolis"
