@@ -15,17 +15,17 @@
 """
 try:
     from PySide6.QtWidgets import QCheckBox, QPushButton, QTextEdit, QFrame, QLabel, QComboBox, QHBoxLayout, QApplication
-    from PySide6.QtCore import Qt, QThread, Signal, QCoreApplication, QTranslator, QLocale
+    from PySide6.QtCore import QThread, Signal, QCoreApplication, QTranslator, QLocale
 except:
     from PyQt5.QtWidgets import QCheckBox, QPushButton, QTextEdit, QFrame, QLabel, QComboBox, QHBoxLayout, QApplication
-    from PyQt5.QtCore import Qt, QThread, QCoreApplication, QTranslator, QLocale
+    from PyQt5.QtCore import QThread, QCoreApplication, QTranslator, QLocale
     from PyQt5.QtCore import pyqtSignal as Signal
 
 from persepolis.scripts.useful_tools import determineConfigFolder
 from persepolis.scripts.addlink import AddLinkWindow
 from persepolis.scripts import logger, osCommands
 from persepolis.scripts.spider import spider
-from time import time, sleep
+from time import time
 from functools import partial
 from random import random
 from copy import deepcopy
@@ -34,7 +34,7 @@ import re
 import os
 
 # write youtube_dl version in log
-logger.sendToLog('youtube_dl version: '
+logger.sendToLog('yt-dlp version: '
                  + str(youtube_dl.version.__version__),
                  'INFO')
 
@@ -80,26 +80,25 @@ class MediaListFetcherThread(QThread):
             self.cookies = self.makeHttpCookie(video_dict['load_cookies'])
 
         # Proxy
-        if 'ip' in video_dict.keys() and video_dict['ip']:
-            try:
-                # ip + port
-                ip_port = 'http://{}:{}'.format(video_dict['ip'], video_dict['port'])
+        if video_dict['ip']:
 
-                if 'referer' in video_dict.keys() and video_dict['proxy_user']:
-                    ip_port = 'http://{}:{}@{}'.format(video_dict['proxy_user'], video_dict['proxy_passwd'], ip_port)
+            # ip + port
+            ip_port = '{}:{}'.format(video_dict['ip'], str(video_dict['port']))
 
-                self.youtube_dl_options_dict['proxy'] = str(ip_port)
-            except:
-                pass
+            if video_dict['proxy_user']:
+                proxy_argument = '{}://{}:{}@{}'.format(video_dict['proxy_type'], video_dict['proxy_user'], video_dict['proxy_passwd'], ip_port)
 
-        if 'download_user' in video_dict.keys() and video_dict['download_user']:
-            try:
-                self.youtube_dl_options_dict['username'] = str(video_dict['download_user'])
-                self.youtube_dl_options_dict['password'] = str(video_dict['download_passwd'])
-            except:
-                pass
+            else:
+                proxy_argument = '{}://{}'.format(video_dict['proxy_type'], ip_port)
 
-        if 'link' in video_dict.keys() and video_dict['link']:
+            self.youtube_dl_options_dict['proxy'] = str(proxy_argument)
+
+        if video_dict['download_user']:
+            
+            self.youtube_dl_options_dict['username'] = str(video_dict['download_user'])
+            self.youtube_dl_options_dict['password'] = str(video_dict['download_passwd'])
+
+        if video_dict['link']:
             self.youtube_link = str(video_dict['link'])
 
     def run(self):
@@ -138,7 +137,7 @@ class MediaListFetcherThread(QThread):
         cookies = '# HTTP cookie file.\n'
         if raw_cookie:
             try:
-                raw_cookies = re.split(';\s*', str(raw_cookie))
+                raw_cookies = re.split(';\\s*', str(raw_cookie))
                 # Format all cookie values as netscape cookie.
                 for c in raw_cookies:
                     key, val = c.split('=', 1)
@@ -168,8 +167,8 @@ class VideoFinderAddLink(AddLinkWindow):
     running_thread = None
     threadPool = {}
 
-    def __init__(self, parent, receiver_slot, settings, video_dict={}):
-        super().__init__(parent, receiver_slot, settings, video_dict)
+    def __init__(self, parent, receiver_slot, socks5_to_http_convertor_is_installed, settings, video_dict={}):
+        super().__init__(parent, receiver_slot, settings, socks5_to_http_convertor_is_installed, video_dict)
         self.setWindowTitle(QCoreApplication.translate("ytaddlink_src_ui_tr", 'Video Finder'))
         self.size_label.hide()
 
@@ -360,9 +359,12 @@ class VideoFinderAddLink(AddLinkWindow):
         dictionary_to_send = deepcopy(self.plugin_add_link_dictionary)
         # More options
         more_options = self.collectMoreOptions()
+
         for k in more_options.keys():
             dictionary_to_send[k] = more_options[k]
+
         dictionary_to_send['link'] = self.link_lineEdit.text()
+        dictionary_to_send['socket-timeout'] = '5'
 
         fetcher_thread = MediaListFetcherThread(self.fetchedResult, dictionary_to_send, self)
         self.parent.threadPool.append(fetcher_thread)
@@ -582,21 +584,41 @@ class VideoFinderAddLink(AddLinkWindow):
     # This method collects additional information like proxy ip, user, password etc.
     def collectMoreOptions(self):
         options = {'ip': None, 'port': None, 'proxy_user': None, 'proxy_passwd': None, 'download_user': None,
-                   'download_passwd': None}
+                   'download_passwd': None, 'proxy_type': None}
+
         if self.proxy_checkBox.isChecked():
+
             options['ip'] = self.ip_lineEdit.text()
             options['port'] = self.port_spinBox.value()
             options['proxy_user'] = self.proxy_user_lineEdit.text()
             options['proxy_passwd'] = self.proxy_pass_lineEdit.text()
+
+            # http, https or socks5 proxy
+            if self.http_radioButton.isChecked() == True:
+
+                options['proxy_type'] = 'http'
+
+            elif self.https_radioButton.isChecked() == True:
+
+                options['proxy_type'] = 'https'
+
+            else:
+
+                options['proxy_type'] = 'socks5'
+
+
         if self.download_checkBox.isChecked():
+            
             options['download_user'] = self.download_user_lineEdit.text()
             options['download_passwd'] = self.download_pass_lineEdit.text()
 
         # These info (keys) are required for spider to find file size, because spider() does not check if key exists.
         additional_info = ['header', 'load_cookies', 'user_agent', 'referer', 'out']
         for i in additional_info:
+
             if i not in self.plugin_add_link_dictionary.keys():
                 options[i] = None
+
         return options
 
     # user submitted information by pressing ok_pushButton, so get information
@@ -654,12 +676,33 @@ class VideoFinderAddLink(AddLinkWindow):
         self.persepolis_setting.setValue(
             'add_link_initialization/download_user', self.download_user_lineEdit.text())
 
+        # http, https or socks5 proxy
+        if self.http_radioButton.isChecked() == True:
+
+            proxy_type = 'http'
+            self.persepolis_setting.setValue(
+                'add_link_initialization/proxy_type', 'http')
+
+        elif self.https_radioButton.isChecked() == True:
+
+            proxy_type = 'https'
+            self.persepolis_setting.setValue(
+                'add_link_initialization/proxy_type', 'https')
+
+        else:
+
+            proxy_type = 'socks5'
+            self.persepolis_setting.setValue(
+                'add_link_initialization/proxy_type', 'socks5')
+
+
         # get proxy information
         if not(self.proxy_checkBox.isChecked()):
             ip = None
             port = None
             proxy_user = None
             proxy_passwd = None
+            proxy_type = None
         else:
             ip = self.ip_lineEdit.text()
             if not(ip):
@@ -725,11 +768,12 @@ class VideoFinderAddLink(AddLinkWindow):
 
         # did user select separate audio and video?
         if len(link_list) == 2:
-            video_name = name + extension
-            audio_name = name + '.' + \
+            video_name = name + "_video" + extension
+            audio_name = name + "_audio" + '.' + \
                 str(self.no_video_list[self.audio_format_selection_comboBox.currentIndex() - 1]['ext'])
 
             name_list = [video_name, audio_name]
+
         else:
             name_list = [name + extension]
 
@@ -768,7 +812,7 @@ class VideoFinderAddLink(AddLinkWindow):
             # save information in a dictionary(add_link_dictionary).
             add_link_dictionary = {'referer': referer, 'header': header, 'user_agent': user_agent, 'load_cookies': load_cookies,
                                    'out': name_list[0], 'start_time': start_time, 'end_time': end_time, 'link': link_list[0], 'ip': ip,
-                                   'port': port, 'proxy_user': proxy_user, 'proxy_passwd': proxy_passwd,
+                                   'port': port, 'proxy_user': proxy_user, 'proxy_passwd': proxy_passwd, 'proxy_type': proxy_type,
                                    'download_user': download_user, 'download_passwd': download_passwd,
                                    'connections': connections, 'limit_value': limit, 'download_path': download_path}
 
@@ -777,13 +821,13 @@ class VideoFinderAddLink(AddLinkWindow):
         else:
             video_add_link_dictionary = {'referer': referer, 'header': header, 'user_agent': user_agent, 'load_cookies': load_cookies,
                                          'out': name_list[0], 'start_time': start_time, 'end_time': end_time, 'link': link_list[0], 'ip': ip,
-                                         'port': port, 'proxy_user': proxy_user, 'proxy_passwd': proxy_passwd,
+                                         'port': port, 'proxy_user': proxy_user, 'proxy_passwd': proxy_passwd, 'proxy_type': proxy_type,
                                          'download_user': download_user, 'download_passwd': download_passwd,
                                          'connections': connections, 'limit_value': limit, 'download_path': download_path}
 
             audio_add_link_dictionary = {'referer': referer, 'header': header, 'user_agent': user_agent, 'load_cookies': load_cookies,
                                          'out': name_list[1], 'start_time': None, 'end_time': end_time, 'link': link_list[1], 'ip': ip,
-                                         'port': port, 'proxy_user': proxy_user, 'proxy_passwd': proxy_passwd,
+                                         'port': port, 'proxy_user': proxy_user, 'proxy_passwd': proxy_passwd, 'proxy_type': proxy_type,
                                          'download_user': download_user, 'download_passwd': download_passwd,
                                          'connections': connections, 'limit_value': limit, 'download_path': download_path}
 
