@@ -14,11 +14,11 @@
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 try:
     from PySide6.QtCore import Qt, QSize, QPoint, QThread, QTranslator, QCoreApplication, QLocale
-    from PySide6.QtWidgets import QLineEdit, QWidget, QSizePolicy,  QInputDialog
+    from PySide6.QtWidgets import QLineEdit, QInputDialog
     from PySide6.QtGui import QIcon
 except:
     from PyQt5.QtCore import Qt, QSize, QPoint, QThread, QTranslator, QCoreApplication, QLocale
-    from PyQt5.QtWidgets import QLineEdit, QWidget, QSizePolicy,  QInputDialog
+    from PyQt5.QtWidgets import QLineEdit, QInputDialog
     from PyQt5.QtGui import QIcon
 
 
@@ -29,7 +29,6 @@ from persepolis.scripts.bubble import notifySend
 from persepolis.scripts import download
 import subprocess
 import platform
-import time
 
 os_type = platform.system()
 
@@ -145,7 +144,7 @@ class VideoFinderProgressWindow(VideoFinderProgressWindow_Ui):
     def pausePushButtonPressed(self, button):
 
         if self.status == "downloading":
-            answer = download.downloadPause(self.gid)
+            answer = download.downloadPause(self.gid, self.parent)
 
             # if aria2 did not respond , then this function is checking for aria2
             # availability , and if aria2 disconnected then aria2Disconnected is
